from rest_framework import exceptions
from rest_framework.authentication import TokenAuthentication

from .models import TimedAuthToken


class TimedAuthTokenAuthentication(TokenAuthentication):
    model = TimedAuthToken

    def authenticate_credentials(self, key):
        try:
            token = self.model.objects.get(key=key)

        except self.model.DoesNotExist:
            raise exceptions.AuthenticationFailed('Invalid token')

        if token.is_expired:
            raise exceptions.AuthenticationFailed('Token has expired')

        if not token.user.is_active:
            raise exceptions.AuthenticationFailed('User inactive or deleted')

        # Since the token was used to authenticate, we can calculate a new
        # expiration date, and update the last used date.
        token.calculate_new_expiration()
        token.save(update_fields=['expires', 'last_used'])

        return token.user, token



from rest_framework.generics import CreateAPIView

from .serializers import TimedAuthTokenCreateSerializer


class TimedAuthTokenCreateView(CreateAPIView):
    authentication_classes = ()
    permission_classes = ()
    serializer_class = TimedAuthTokenCreateSerializer



from setuptools import setup


def read(filename):
    with open(filename) as f:
        return f.read()


setup(
    name='djangorestframework-timed-auth-token',
    version='1.0.2',
    description=('An authentication token for djangorestframework that has an expiration date.'),
    long_description=read('README.rst'),
    author='Ryan Pineo',
    author_email='ryanpineo@gmail.com',
    license='MIT',
    url='https://github.com/silverlogic/djangorestframework-timed-auth-token',
    packages=['timed_auth_token', 'timed_auth_token.migrations'],
    install_requires=['djangorestframework>=3.1'],
    classifiers=[
        'Framework :: Django',
        'Programming Language :: Python :: 3'
    ]
)
